@@ -36,6 +36,7 @@ import abc
 import shutil
 import tempfile
 import warnings
+from distutils.version import StrictVersion
 
 import six
 from six.moves.urllib.request import urlopen
@@ -212,7 +213,10 @@ class ArrayComparison(object):
 
     def pytest_runtest_setup(self, item):
 
-        compare = item.keywords.get('array_compare')
+        if StrictVersion(pytest.__version__) < StrictVersion("3.6"):
+            compare = item.get_marker('array_compare')
+        else:
+            compare = item.get_closest_marker('array_compare')
 
         if compare is None:
             return
